@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2005, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -41,10 +41,10 @@ import java.util.Properties;
 import java.util.Set;
 import java.util.SortedMap;
 
-import testsuite.BaseTestCase;
-
 import com.mysql.jdbc.CharsetMapping;
 
+import testsuite.BaseTestCase;
+
 public class CharsetTest extends BaseTestCase {
 
     public CharsetTest(String name) {
@@ -287,116 +287,121 @@ public class CharsetTest extends BaseTestCase {
         this.pstmt.executeUpdate();
 
         String query = "SELECT include_blob, include_tinyblob, include_longblob, exclude_tinyblob, exclude_blob, exclude_longblob FROM utf8Test";
-        this.rs = utf8Conn.createStatement().executeQuery(query);
-        this.rs.next();
+        ResultSet rset = utf8Conn.createStatement().executeQuery(query);
+        rset.next();
 
-        assertEquals(this.rs.getObject(1).toString(), outsideBmp);
-        assertEquals(this.rs.getObject(2).toString(), outsideBmp);
-        assertEquals(this.rs.getObject(3).toString(), outsideBmp);
-        assertEquals(this.rs.getObject(4).toString(), outsideBmp);
-        assertEquals(this.rs.getObject(5).toString(), outsideBmp);
-        assertEquals(this.rs.getObject(6).toString(), outsideBmp);
+        assertEquals(rset.getObject(1).toString(), outsideBmp);
+        assertEquals(rset.getObject(2).toString(), outsideBmp);
+        assertEquals(rset.getObject(3).toString(), outsideBmp);
+        assertEquals(rset.getObject(4).toString(), outsideBmp);
+        assertEquals(rset.getObject(5).toString(), outsideBmp);
+        assertEquals(rset.getObject(6).toString(), outsideBmp);
 
-        assertEquals("java.lang.String", this.rs.getObject(1).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(1));
-        assertEquals(Types.VARCHAR, this.rs.getMetaData().getColumnType(1));
+        assertEquals("java.lang.String", rset.getObject(1).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(1));
+        assertEquals(Types.VARCHAR, rset.getMetaData().getColumnType(1));
 
-        assertEquals("java.lang.String", this.rs.getObject(2).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(2));
-        assertEquals(Types.VARCHAR, this.rs.getMetaData().getColumnType(2));
+        assertEquals("java.lang.String", rset.getObject(2).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(2));
+        assertEquals(Types.VARCHAR, rset.getMetaData().getColumnType(2));
 
-        assertEquals("java.lang.String", this.rs.getObject(3).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(3));
-        assertEquals(Types.LONGVARCHAR, this.rs.getMetaData().getColumnType(3));
+        assertEquals("java.lang.String", rset.getObject(3).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(3));
+        assertEquals(Types.LONGVARCHAR, rset.getMetaData().getColumnType(3));
 
-        assertEquals("java.lang.String", this.rs.getObject(4).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(4));
-        assertEquals(Types.VARCHAR, this.rs.getMetaData().getColumnType(4));
+        assertEquals("java.lang.String", rset.getObject(4).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(4));
+        assertEquals(Types.VARCHAR, rset.getMetaData().getColumnType(4));
 
-        assertEquals("java.lang.String", this.rs.getObject(5).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(5));
-        assertEquals(Types.VARCHAR, this.rs.getMetaData().getColumnType(5));
+        assertEquals("java.lang.String", rset.getObject(5).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(5));
+        assertEquals(Types.VARCHAR, rset.getMetaData().getColumnType(5));
 
-        assertEquals("java.lang.String", this.rs.getObject(6).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(6));
-        assertEquals(Types.LONGVARCHAR, this.rs.getMetaData().getColumnType(6));
+        assertEquals("java.lang.String", rset.getObject(6).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(6));
+        assertEquals(Types.LONGVARCHAR, rset.getMetaData().getColumnType(6));
 
-        utf8Conn = getConnectionWithProps("useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern=.*include.*,utf8OutsideBmpExcludedColumnNamePattern=.*blob");
+        utf8Conn = getConnectionWithProps(
+                "useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern=.*include.*,utf8OutsideBmpExcludedColumnNamePattern=.*blob");
 
-        this.rs = utf8Conn.createStatement().executeQuery(query);
-        this.rs.next();
+        rset = utf8Conn.createStatement().executeQuery(query);
+        rset.next();
 
         // Should walk/talk like a string, encoded in utf-8 on the server (4-byte)
-        assertEquals(this.rs.getObject(1).toString(), outsideBmp);
-        assertEquals(this.rs.getObject(2).toString(), outsideBmp);
-        assertEquals(this.rs.getObject(3).toString(), outsideBmp);
+        assertEquals(rset.getObject(1).toString(), outsideBmp);
+        assertEquals(rset.getObject(2).toString(), outsideBmp);
+        assertEquals(rset.getObject(3).toString(), outsideBmp);
 
-        assertEquals("java.lang.String", this.rs.getObject(1).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(1));
-        assertEquals(Types.VARCHAR, this.rs.getMetaData().getColumnType(1));
+        assertEquals("java.lang.String", rset.getObject(1).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(1));
+        assertEquals(Types.VARCHAR, rset.getMetaData().getColumnType(1));
 
-        assertEquals("java.lang.String", this.rs.getObject(2).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(2));
-        assertEquals(Types.VARCHAR, this.rs.getMetaData().getColumnType(2));
+        assertEquals("java.lang.String", rset.getObject(2).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(2));
+        assertEquals(Types.VARCHAR, rset.getMetaData().getColumnType(2));
 
-        assertEquals("java.lang.String", this.rs.getObject(3).getClass().getName());
-        assertEquals("java.lang.String", this.rs.getMetaData().getColumnClassName(3));
-        assertEquals(Types.LONGVARCHAR, this.rs.getMetaData().getColumnType(3));
+        assertEquals("java.lang.String", rset.getObject(3).getClass().getName());
+        assertEquals("java.lang.String", rset.getMetaData().getColumnClassName(3));
+        assertEquals(Types.LONGVARCHAR, rset.getMetaData().getColumnType(3));
 
         // These should be left as a blob, since it matches the exclusion regex
-        assertTrue(bytesAreSame(this.rs.getBytes(4), outsideBmpBytes));
-        assertEquals("[B", this.rs.getObject(4).getClass().getName());
-        assertEquals("[B", this.rs.getMetaData().getColumnClassName(4));
-        assertEquals(Types.VARBINARY, this.rs.getMetaData().getColumnType(4));
+        assertTrue(bytesAreSame(rset.getBytes(4), outsideBmpBytes));
+        assertEquals("[B", rset.getObject(4).getClass().getName());
+        assertEquals("[B", rset.getMetaData().getColumnClassName(4));
+        assertEquals(Types.VARBINARY, rset.getMetaData().getColumnType(4));
 
         // Should behave types-wise just like BLOB, including LONGVARBINARY type mapping
-        assertTrue(bytesAreSame(this.rs.getBytes(5), outsideBmpBytes));
-        assertEquals("[B", this.rs.getObject(5).getClass().getName());
-        assertEquals("[B", this.rs.getMetaData().getColumnClassName(5));
-        assertEquals(Types.LONGVARBINARY, this.rs.getMetaData().getColumnType(5));
+        assertTrue(bytesAreSame(rset.getBytes(5), outsideBmpBytes));
+        assertEquals("[B", rset.getObject(5).getClass().getName());
+        assertEquals("[B", rset.getMetaData().getColumnClassName(5));
+        assertEquals(Types.LONGVARBINARY, rset.getMetaData().getColumnType(5));
 
-        assertTrue(bytesAreSame(this.rs.getBytes(6), outsideBmpBytes));
-        assertEquals("[B", this.rs.getObject(6).getClass().getName());
-        assertEquals("[B", this.rs.getMetaData().getColumnClassName(6));
-        assertEquals(Types.LONGVARBINARY, this.rs.getMetaData().getColumnType(6));
+        assertTrue(bytesAreSame(rset.getBytes(6), outsideBmpBytes));
+        assertEquals("[B", rset.getObject(6).getClass().getName());
+        assertEquals("[B", rset.getMetaData().getColumnClassName(6));
+        assertEquals(Types.LONGVARBINARY, rset.getMetaData().getColumnType(6));
 
         //
         // Check error handling
         //
 
-        utf8Conn = getConnectionWithProps("useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern={{,utf8OutsideBmpExcludedColumnNamePattern={{");
+        utf8Conn = getConnectionWithProps(
+                "useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern={{,utf8OutsideBmpExcludedColumnNamePattern={{");
 
         try {
-            utf8Conn.createStatement().executeQuery(query);
+            rset = utf8Conn.createStatement().executeQuery(query);
             fail("Expected an exception");
         } catch (SQLException sqlEx) {
             assertNotNull(sqlEx.getCause());
             assertEquals("java.util.regex.PatternSyntaxException", sqlEx.getCause().getClass().getName());
         }
 
-        utf8Conn = getConnectionWithProps("useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern={{,utf8OutsideBmpExcludedColumnNamePattern=.*");
+        utf8Conn = getConnectionWithProps(
+                "useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern={{,utf8OutsideBmpExcludedColumnNamePattern=.*");
 
         try {
-            utf8Conn.createStatement().executeQuery(query);
+            rset = utf8Conn.createStatement().executeQuery(query);
             fail("Expected an exception");
         } catch (SQLException sqlEx) {
             assertNotNull(sqlEx.getCause());
             assertEquals("java.util.regex.PatternSyntaxException", sqlEx.getCause().getClass().getName());
         }
 
-        utf8Conn = getConnectionWithProps("useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern={{,utf8OutsideBmpExcludedColumnNamePattern={{,paranoid=true");
+        utf8Conn = getConnectionWithProps(
+                "useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern={{,utf8OutsideBmpExcludedColumnNamePattern={{,paranoid=true");
 
         try {
-            utf8Conn.createStatement().executeQuery(query);
+            rset = utf8Conn.createStatement().executeQuery(query);
             fail("Expected an exception");
         } catch (SQLException sqlEx) {
             assertNull(sqlEx.getCause());
         }
 
-        utf8Conn = getConnectionWithProps("useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern={{,utf8OutsideBmpExcludedColumnNamePattern=.*,paranoid=true");
+        utf8Conn = getConnectionWithProps(
+                "useBlobToStoreUTF8OutsideBMP=true, characterEncoding=UTF-8,utf8OutsideBmpIncludedColumnNamePattern={{,utf8OutsideBmpExcludedColumnNamePattern=.*,paranoid=true");
 
         try {
-            utf8Conn.createStatement().executeQuery(query);
+            rset = utf8Conn.createStatement().executeQuery(query);
             fail("Expected an exception");
         } catch (SQLException sqlEx) {
             assertNull(sqlEx.getCause());
